==> kldpOpenBar?action=download&value=kldpbar-0.0.1.zip: content/kldpbar.js <==
  var Atype=0;
  var Stype="";
  var Dtype=0;
  var altclickdicStarted = false;
    
  function KLDPOpenBarLoadPage(url){
      window.content.document.location.href=url;
  }  
    
  function KLDPOpenBarSearch(Stype){
      var mySearchMenuList = document.getElementById('KLDPOpenBarSearchText');

      var mySearchTerm = mySearchMenuList.value;

      if (mySearchTerm == '') { return; }

       if (Stype== 'kldpnet' ) 
		   var mySearchTermUni = unicode2ascii(mySearchTerm,"EUC-KR")
      else
		   var mySearchTerm = unicode2ascii(mySearchTerm,"EUC-KR")

      if (Stype == '' || Stype== 'kldpbbs' ) { var mySearchString = "http://bbs.kldp.org/search.php?mode=results&search_forum=-1&search_time=0&search_terms=any&search_cat=-1&sort_by=0&sort_dir=DESC&show_results=topics&search_fields=all&return_chars=200&search_keywords=" + escape(mySearchTerm); }
      if (Stype== 'kldpwiki' ) { var mySearchString = "http://wiki.kldp.org/wiki.php/?action=goto&value=" + escape(mySearchTerm); }
      if (Stype== 'kldpnet' ) { var mySearchString = "http://kldp.net/search/?type_of_search=soft&words=" + mySearchTerm ; }

      Stype="";

	  var url = mySearchTerm;

	  if (url.substr(0,7) == 'http://') {
		  url = url.replace( /^\s+/, "");
		  url = url.replace( /\s+$/, "");

		  mySearchString = url;
	  }
		
	  if (url.substr(0,4) == 'www.') {
		  url = url.replace( /^\s+/, "");
		  url = url.replace( /\s+$/, "");

		  mySearchString = 'http://'+url;
	  }
       
      KLDPOpenBarLoadPage(mySearchString);

    }    


	function KLDPOpenBarMenuAction(Atype) {
    
      if (Atype == 0 ) { KLDPOpenBarLoadPage('http://kldp.org'); }
      if (Atype == 1 ) { KLDPOpenBarLoadPage('http://bbs.kldp.org'); }
      if (Atype == 2 ) { KLDPOpenBarLoadPage('http://wiki.kldp.org'); }
      if (Atype == 3 ) { KLDPOpenBarLoadPage('http://kldp.net'); }

      if (Atype == 5 ) { window.alert('Underconstruction. '); }
      if (Atype == 6 ) { window.alert('Underconstruction. '); }

      if (Atype == 11 ) { KLDPOpenBarLoadPage('http://qmail.kldp.org'); }
      if (Atype == 12 ) { KLDPOpenBarLoadPage('http://kltp.kldp.org'); }
      if (Atype == 13 ) { KLDPOpenBarLoadPage('http://mutt.kldp.org'); }
      if (Atype == 14 ) { KLDPOpenBarLoadPage('http://weblog.kldp.org'); }
      if (Atype == 15 ) { KLDPOpenBarLoadPage('http://ktug.kldp.org'); }
      if (Atype == 16 ) { KLDPOpenBarLoadPage('http://docbook.or.kr'); }
      if (Atype == 17 ) { KLDPOpenBarLoadPage('http://lisp.kldp.org'); }
      if (Atype == 18 ) { KLDPOpenBarLoadPage('http://jsboard.kldp.org'); }
      if (Atype == 19 ) { KLDPOpenBarLoadPage('http://man.kldp.org'); }

      if (Atype == 61 ) { KLDPOpenBarLoadPage('http://people.kldp.org/~eunjea'); }
      if (Atype == 62 ) { KLDPOpenBarLoadPage('http://people.kldp.org/~krisna'); }
      if (Atype == 63 ) { KLDPOpenBarLoadPage('http://people.kldp.org/~akpil'); }

      if (Atype == 99 ) { 
  		  resultswin = window.open( "chrome://kldpbar/content/about.html", "about", "fullscreen=no,resizable=no,scrollbars=no,toolbar=no,menubar=no,directories=no,copyhistory=no,status=no,height=200,width=240,location=no" );
      	dofocus( resultswin );
      }
      
      Atype=0;
    }



    function KLDPOpenBarLeftMenuSearch() {
    }

    function KLDPOpenBarLeftMenuSearchDic() {
    }



  function unicode2ascii(sourcestr,charset) {  
  	const usvc = Components.classes['@mozilla.org/intl/scriptableunicodeconverter'].getService(Components.interfaces.nsIScriptableUnicodeConverter);
  	usvc.charset = charset;
    var retstr = usvc.ConvertFromUnicode(sourcestr);
    return retstr;
  }

  function ascii2unicode(sourcestr,charset) {  
  	const usvc = Components.classes['@mozilla.org/intl/scriptableunicodeconverter'].getService(Components.interfaces.nsIScriptableUnicodeConverter);
  	usvc.charset = charset;
    var retstr = usvc.ConvertToUnicode(sourcestr);
    return retstr;
  }

  function altclickdicMouseDown(ea) {  

    if (!ea.altKey) return false;
  	  
    t = ea.rangeOffset;
    w = ea.rangeParent.nodeValue;

    ta = ea.target.nodeName;

    	switch( ta ) {
		    case "IMG":
			    w = target.alt;
			  break;
				
		    case "A":
          return;
			  break;
				
    		case "INPUT":
		    	switch( ea.target.type ) {
				    case "image":
				    	w = ea.target.alt;
					  break;
	       	  default:
		  	  	  w = target.text;
		  	    break;
		  	  }
			  break;
			
		    default:
			  break;
    }
    
    i = 0;
    t_prev = t-1;
    t_next = t+1;
    t_count = 0;

    while(t_prev > 0 && t_count <= 10) {
    	if ((w.charCodeAt(t_prev) <= 47)
  	    || ((w.charCodeAt(t_prev) >= 58) && (w.charCodeAt(t_prev) <= 64))
  	    || ((w.charCodeAt(t_prev) >= 91) && (w.charCodeAt(t_prev) <= 95))
       	|| ((w.charCodeAt(t_prev) >= 123) && (w.charCodeAt(t_prev) <= 1169))
  	    || ((w.charCodeAt(t_prev) >= 7808) && (w.charCodeAt(t_prev) <= 12309))
  	    || ((w.charCodeAt(t_prev) >= 12800) && (w.charCodeAt(t_prev) <= 13277))
  	    || ((w.charCodeAt(t_prev) >= 64012) && (w.charCodeAt(t_prev) <= 65295))
  	    || ((w.charCodeAt(t_prev) >= 65306) && (w.charCodeAt(t_prev) <= 65312))
  	    || ((w.charCodeAt(t_prev) >= 65339) && (w.charCodeAt(t_prev) <= 65344))
   	    || (w.charCodeAt(t_prev) >= 65371)) { t_prev++; break; }
    	t_prev = t_prev -1;
    	t_count ++;
    }
  
    t_count = 0;
    while(t_next < w.length && t_count <= 10) {
    	if ((w.charCodeAt(t_next) <= 47)
  	    || ((w.charCodeAt(t_next) >= 58) && (w.charCodeAt(t_next) <= 64))
  	    || ((w.charCodeAt(t_next) >= 91) && (w.charCodeAt(t_next) <= 95))
      	|| ((w.charCodeAt(t_next) >= 123) && (w.charCodeAt(t_next) <= 1169))
  	    || ((w.charCodeAt(t_next) >= 7808) && (w.charCodeAt(t_next) <= 12309))
  	    || ((w.charCodeAt(t_next) >= 12800) && (w.charCodeAt(t_next) <= 13277))
  	    || ((w.charCodeAt(t_next) >= 64012) && (w.charCodeAt(t_next) <= 65295))
  	    || ((w.charCodeAt(t_next) >= 65306) && (w.charCodeAt(t_next) <= 65312))
  	    || ((w.charCodeAt(t_next) >= 65339) && (w.charCodeAt(t_next) <= 65344))
   	    || (w.charCodeAt(t_next) >= 65371)) break;
  	  t_next = t_next + 1;
  	  t_count ++;
    }

    find_w = w.substring(t_prev,t_next);

    find_w.replace(/^\s*([\s\S]*\S+)\s*$|^\s*$/,'$1');

    if (find_w.length > 1 && find_w.length < 64) {	
  		var dic_url = '?j=2&query='+escape(unicode2ascii(find_w,"EUC-KR"));
  	  resultswin = window.open( dic_url, "minidic", "fullscreen=no,resizable=yes,scrollbars=yes,toolbar=no,menubar=no,directories=no,copyhistory=no,status=no,height=450,width=358,location=no" );
    	dofocus( resultswin );
  	}
    
  }

  function altclickdicInit() {
    document.getElementById("content").mPanelContainer.addEventListener("mousedown", altclickdicMouseDown, true);
	  altclickdicStarted = true;
  }

==> kldpOpenBar?action=download&value=kldpbar-0.0.2.zip: content/kldpbar.js <==
  var Atype=0;
  var Stype="";
  var Dtype=0;
  var altclickkldpStarted = false;
    
  function KLDPOpenBarLoadPage(url){
      window.content.document.location.href=url;
  }  
    
  function KLDPOpenBarSearch(Stype){
      var mySearchMenuList = document.getElementById('KLDPOpenBarSearchText');

      var mySearchTerm = mySearchMenuList.value;

      if (mySearchTerm == '') { return; }

       if (Stype== 'kldpnet' ) 
		   var mySearchTermUni = unicode2ascii(mySearchTerm,"EUC-KR")
      else
		   var mySearchTerm = unicode2ascii(mySearchTerm,"EUC-KR")

      if (Stype == '' || Stype== 'kldpbbs' ) { var mySearchString = "http://bbs.kldp.org/search.php?mode=results&search_forum=-1&search_time=0&search_terms=any&search_cat=-1&sort_by=0&sort_dir=DESC&show_results=topics&search_fields=all&return_chars=200&search_keywords=" + escape(mySearchTerm); }
      if (Stype== 'kldpwiki' ) { var mySearchString = "http://wiki.kldp.org/wiki.php/?action=goto&value=" + escape(mySearchTerm); }
      if (Stype== 'kldpnet' ) { var mySearchString = "http://kldp.net/search/?type_of_search=soft&words=" + mySearchTerm ; }

      Stype="";

	  var url = mySearchTerm;

	  if (url.substr(0,7) == 'http://') {
		  url = url.replace( /^\s+/, "");
		  url = url.replace( /\s+$/, "");

		  mySearchString = url;
	  }
		
	  if (url.substr(0,4) == 'www.') {
		  url = url.replace( /^\s+/, "");
		  url = url.replace( /\s+$/, "");

		  mySearchString = 'http://'+url;
	  }
       
      KLDPOpenBarLoadPage(mySearchString);

    }    


	function KLDPOpenBarMenuAction(Atype) {
    
      if (Atype == 0 ) { KLDPOpenBarLoadPage('http://kldp.org'); }
      if (Atype == 1 ) { KLDPOpenBarLoadPage('http://bbs.kldp.org'); }
      if (Atype == 2 ) { KLDPOpenBarLoadPage('http://wiki.kldp.org'); }
      if (Atype == 3 ) { KLDPOpenBarLoadPage('http://kldp.net'); }

      if (Atype == 5 ) { window.alert('Underconstruction. '); }
      if (Atype == 6 ) { window.alert('Underconstruction. '); }

      if (Atype == 11 ) { KLDPOpenBarLoadPage('http://qmail.kldp.org'); }
      if (Atype == 12 ) { KLDPOpenBarLoadPage('http://kltp.kldp.org'); }
      if (Atype == 13 ) { KLDPOpenBarLoadPage('http://mutt.kldp.org'); }
      if (Atype == 14 ) { KLDPOpenBarLoadPage('http://weblog.kldp.org'); }
      if (Atype == 15 ) { KLDPOpenBarLoadPage('http://ktug.kldp.org'); }
      if (Atype == 16 ) { KLDPOpenBarLoadPage('http://docbook.or.kr'); }
      if (Atype == 17 ) { KLDPOpenBarLoadPage('http://lisp.kldp.org'); }
      if (Atype == 18 ) { KLDPOpenBarLoadPage('http://jsboard.kldp.org'); }
      if (Atype == 19 ) { KLDPOpenBarLoadPage('http://man.kldp.org'); }

      if (Atype == 61 ) { KLDPOpenBarLoadPage('http://people.kldp.org/~eunjea'); }
      if (Atype == 62 ) { KLDPOpenBarLoadPage('http://people.kldp.org/~krisna'); }
      if (Atype == 63 ) { KLDPOpenBarLoadPage('http://people.kldp.org/~akpil'); }

      if (Atype == 99 ) { 
  		  resultswin = window.open( "chrome://kldpbar/content/about.html", "about", "fullscreen=no,resizable=no,scrollbars=no,toolbar=no,menubar=no,directories=no,copyhistory=no,status=no,height=200,width=240,location=no" );
      	dofocus( resultswin );
      }
      
      Atype=0;
    }

 

  function unicode2ascii(sourcestr,charset) {  
  	const usvc = Components.classes['@mozilla.org/intl/scriptableunicodeconverter'].getService(Components.interfaces.nsIScriptableUnicodeConverter);
  	usvc.charset = charset;
    var retstr = usvc.ConvertFromUnicode(sourcestr);
    return retstr;
  }

  function ascii2unicode(sourcestr,charset) {  
  	const usvc = Components.classes['@mozilla.org/intl/scriptableunicodeconverter'].getService(Components.interfaces.nsIScriptableUnicodeConverter);
  	usvc.charset = charset;
    var retstr = usvc.ConvertToUnicode(sourcestr);
    return retstr;
  }

  function altclickkldpMouseDown(ea) {  

    if (!ea.altKey) return false;
  	  
    t = ea.rangeOffset;
    w = ea.rangeParent.nodeValue;

    ta = ea.target.nodeName;

    	switch( ta ) {
		    case "IMG":
			    w = target.alt;
			  break;
				
		    case "A":
				  return;
			  break;
				
    		case "INPUT":
		    	switch( ea.target.type ) {
				    case "image":
				    	w = ea.target.alt;
					  break;
	       	  default:
		  	  	  w = target.text;
		  	    break;
		  	  }
			  break;
			
		    default:
			  break;
    }
    
    i = 0;
    t_prev = t-1;
    t_next = t+1;
    t_count = 0;

    while(t_prev > 0 && t_count <= 10) {
    	if ((w.charCodeAt(t_prev) <= 47)
  	    || ((w.charCodeAt(t_prev) >= 58) && (w.charCodeAt(t_prev) <= 64))
  	    || ((w.charCodeAt(t_prev) >= 91) && (w.charCodeAt(t_prev) <= 95))
       	|| ((w.charCodeAt(t_prev) >= 123) && (w.charCodeAt(t_prev) <= 1169))
  	    || ((w.charCodeAt(t_prev) >= 7808) && (w.charCodeAt(t_prev) <= 12309))
  	    || ((w.charCodeAt(t_prev) >= 12800) && (w.charCodeAt(t_prev) <= 13277))
  	    || ((w.charCodeAt(t_prev) >= 64012) && (w.charCodeAt(t_prev) <= 65295))
  	    || ((w.charCodeAt(t_prev) >= 65306) && (w.charCodeAt(t_prev) <= 65312))
  	    || ((w.charCodeAt(t_prev) >= 65339) && (w.charCodeAt(t_prev) <= 65344))
   	    || (w.charCodeAt(t_prev) >= 65371)) { t_prev++; break; }
    	t_prev = t_prev -1;
    	t_count ++;
    }
  
    t_count = 0;
    while(t_next < w.length && t_count <= 10) {
    	if ((w.charCodeAt(t_next) <= 47)
  	    || ((w.charCodeAt(t_next) >= 58) && (w.charCodeAt(t_next) <= 64))
  	    || ((w.charCodeAt(t_next) >= 91) && (w.charCodeAt(t_next) <= 95))
      	|| ((w.charCodeAt(t_next) >= 123) && (w.charCodeAt(t_next) <= 1169))
  	    || ((w.charCodeAt(t_next) >= 7808) && (w.charCodeAt(t_next) <= 12309))
  	    || ((w.charCodeAt(t_next) >= 12800) && (w.charCodeAt(t_next) <= 13277))
  	    || ((w.charCodeAt(t_next) >= 64012) && (w.charCodeAt(t_next) <= 65295))
  	    || ((w.charCodeAt(t_next) >= 65306) && (w.charCodeAt(t_next) <= 65312))
  	    || ((w.charCodeAt(t_next) >= 65339) && (w.charCodeAt(t_next) <= 65344))
   	    || (w.charCodeAt(t_next) >= 65371)) break;
  	  t_next = t_next + 1;
  	  t_count ++;
    }

    find_w = w.substring(t_prev,t_next);

    find_w.replace(/^\s*([\s\S]*\S+)\s*$|^\s*$/,'$1');


    var mySearchMenuList = document.getElementById('KLDPOpenBarSearchText');
    mySearchMenuList.value = find_w ;


    if (find_w.length > 1 && find_w.length < 64) {	

	    if ( ea.shiftKey ) 
			var kldp_url = 'http://wiki.kldp.org/wiki.php/?action=goto&value='+escape(unicode2ascii(find_w,"EUC-KR"));
	    else if ( ea.ctrlKey ) 
			var kldp_url = 'http://kldp.net/search/?type_of_search=soft&words='+ find_w ;
		else
			var kldp_url = 'http://bbs.kldp.org/search.php?mode=results&search_forum=-1&search_time=0&search_terms=any&search_cat=-1&sort_by=0&sort_dir=DESC&show_results=topics&search_fields=all&return_chars=200&search_keywords='+escape(unicode2ascii(find_w,"EUC-KR"));


  	  resultswin = window.open( kldp_url, "minikldp", "fullscreen=no,resizable=yes,scrollbars=yes,toolbar=no,menubar=no,directories=no,copyhistory=no,status=no,width=720,height=550,location=no" );
    	dofocus( resultswin );
  	}
    
  }

  function altclickkldpInit() {
    document.getElementById("content").mPanelContainer.addEventListener("mousedown", altclickkldpMouseDown, true);
	  altclickkldpStarted = true;
  }
